@@ -1,6 +1,9 @@
 import logging, sys, re
 from colorama import Fore, Style
 import coloredlogs, tailer
+from functools import wraps
+
+# print('hello worlds 2')
 
 ########################################################################################################################
 # Create colors for the output
@@ -22,7 +25,7 @@ class MyFormatter(logging.Formatter):
 ########################################################################################################################
 # Log to console and to file
 class MCLogger(object):
-	logInst = None 
+	log_inst = None 
 	logfilepath = ""
 	config = []
 
@@ -30,6 +33,8 @@ class MCLogger(object):
 	def __init__(self, out_filename):
 		self._filename = out_filename
 
+		self._setupLogger()
+
 	################################################################################################
 	# Get last n_rows from the log
 	def read_log_file(self, last_n_rows = 20):
@@ -48,26 +53,49 @@ class MCLogger(object):
 	################################################################################################
 	# Configure logger
 	def _setupLogger(self):
-		logInst = logging.getLogger(__name__)
+		self.log_inst = logging.getLogger(__name__)
 
 		custom_formatter = MyFormatter()
-		logInst.setLevel(logging.DEBUG)
+		self.log_inst.setLevel(logging.DEBUG)
 
 		fileHandler = logging.FileHandler( self._filename)
 		fileHandler.setFormatter(custom_formatter)
-		logInst.addHandler(fileHandler)
+		self.log_inst.addHandler(fileHandler)
 
 		consoleHandler = logging.StreamHandler(sys.stdout)
 		consoleHandler.setFormatter(custom_formatter)
-		logInst.addHandler(consoleHandler)
-		logInst.read_log_file_as_text = self.read_log_file_as_text
-		logInst.read_log_file  = self.read_log_file  
+		self.log_inst.addHandler(consoleHandler)
+		self.log_inst.read_log_file_as_text = self.read_log_file_as_text
+		self.log_inst.read_log_file  = self.read_log_file  
 
-		return logInst
+		# return self.log_inst
 
 	################################################################################################
 	# Main function to call
-	def getLogger(self): 
-		if self.logInst	== None:
-			self.logInst	= self._setupLogger( )
-		return self.logInst	 	
\ No newline at end of file
+	# def getLogger(self): 
+	# 	if self.log_inst	== None:
+	# 		self.log_inst	= self._setupLogger( )
+	# 	return self.log_inst	 	
+
+	def logfunc_loc(self, original_func): 
+		def wrapper_func( *args, **kwargs):	 
+			self.debug( f"{Fore.GREEN}>>{original_func.__module__}::{original_func.__qualname__} {Style.RESET_ALL} ARGS[{args}] KWARGS[{kwargs}]")
+			return original_func(*args, **kwargs)	 
+		return wrapper_func
+
+	@classmethod
+	def logfunc_cls(cls, logger_attrib_name ):
+		def main_decorator(  original_func): 
+			def wrapper_func( *args, **kwargs):	 
+				log_ref = getattr( args[0],logger_attrib_name, None )
+				if log_ref: log_ref.debug( f"{Fore.GREEN}>>{original_func.__module__}::{original_func.__qualname__} {Style.RESET_ALL}	 ARGS[{args}] KWARGS[{kwargs}]")	
+				return original_func(*args, **kwargs)	 
+			return wrapper_func
+		return main_decorator
+
+
+	def debug(self, message): self.log_inst.debug(message)
+	def error(self, message): self.log_inst.error(message)
+	def warning(self, message): self.log_inst.warning(message)
+	def info(self, message): self.log_inst.info(message)
+	
